import java.sql.*;
import java.util.*;
import javax.swing.*;
import java.text.*;
import java.io.*;

/**
 * Clase static encargada de realizar I/O sobre la base de datos
 * al estilo de DataIO pero con mayor nivel de abstraccion
 * 
 * @author G.Cherencio
 * @version 1.0
 */
public class Data {
    /**
     * Devuelve la lista de Productos
     */
    public static List<Producto> getProductos() {
        return getProductos("SELECT * FROM TBL_PRODUCTO ORDER BY DESCR ASC");
    }
    public static List<Producto> getProductos(final String query) {
        ResultSet rs = DataIO.getResultSet(query);
        List<Producto> lst = new ArrayList<Producto>();
        try {
            // cargo lista de Productos
            while(rs.next()) {
                lst.add(new Producto(rs.getInt("idp"),rs.getString("descr"),rs.getDouble("precio_base"),rs.getInt("stock")));
            }
            rs.close();
        } catch(SQLException sqle) {
            System.err.println("Data.getProductos(): Error "+sqle.getMessage());
        }
        return lst;
    }
    /**
     * Devuelve la lista de Clientes
     */
    public static List<Cliente> getClientes() {
        return getClientes("SELECT * FROM TBL_CLIENTE ORDER BY DESCR ASC");
    }
    public static List<Cliente> getClientes(final String query) {
        ResultSet rs = DataIO.getResultSet(query);
        List<Cliente> lstc = new ArrayList<Cliente>();
        try {
            // cargo lista de Clientes
            while(rs.next()) {
                lstc.add(new Cliente(rs.getInt("idc"),rs.getString("descr"),rs.getDouble("saldo")));
            }
            rs.close();
        } catch(SQLException sqle) {
            System.err.println("ProductoComboModel(): Error "+sqle.getMessage());
        }
        return lstc;
    }
    /**
     * Devuelve un arreglo de facturas confirmadas o no confirmadas
     * segun se indique en parametro
     * param @confirmada true/false indicado si esta confirmada o no
     * @return lista de objetos Factura
     */
    public static List<Factura> getFacturas(final boolean confirmada) {
        ResultSet rs = DataIO.getResultSet("SELECT * FROM TBL_FACTURA WHERE ESTADO = '"+ ((confirmada) ? "1" : "0") +"' ORDER BY FECHA ASC");
        List<Factura> lstc = new ArrayList<Factura>();
        try {
            // cargo lista de Clientes
            Factura f = null;
            while(rs.next()) {
                f=new Factura(rs.getInt("nro"),rs.getDate("fecha"),new Cliente(rs.getInt("idc")),rs.getDouble("monto"));
                //if ( rs.getString("estado").equals("0") ) f.setConfirmada(true);
                //else f.setConfirmada(false);
                //if ( rs.getString("pagada").equals("0") ) f.setPagada(true);
                //else f.setPagada(false);
                lstc.add(f);
            }
            rs.close();
        } catch(SQLException sqle) {
            System.err.println("Data.getFacturas(): Error "+sqle.getMessage());
        }
        return lstc;
    }
    /**
     * Devuelve un arreglo de facturas pagas o no pagas
     * segun se indique en parametro
     * param @pagada true/false indicado si esta pagada o no
     * @return lista de objetos Factura
     */
    public static List<Factura> getFacturasPagas(final boolean pagada) {
        ResultSet rs = DataIO.getResultSet("SELECT * FROM TBL_FACTURA WHERE PAGADA = '"+ ((pagada) ? "1" : "0") +"' ORDER BY FECHA ASC");
        List<Factura> lstc = new ArrayList<Factura>();
        try {
            // cargo lista de Clientes
            Factura f = null;
            while(rs.next()) {
                f=new Factura(rs.getInt("nro"),rs.getDate("fecha"),new Cliente(rs.getInt("idc")),rs.getDouble("monto"));
                //if ( rs.getString("estado").equals("0") ) f.setConfirmada(true);
                //else f.setConfirmada(false);
                //if ( rs.getString("pagada").equals("0") ) f.setPagada(true);
                //else f.setPagada(false);
                lstc.add(f);
            }
            rs.close();
        } catch(SQLException sqle) {
            System.err.println("Data.getFacturasPagas(): Error "+sqle.getMessage());
        }
        return lstc;
    }
    
}
